/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DInput.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 85 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 88 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 91 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 94 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 97 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 103 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 112 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 123 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 136 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 151 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 168 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 187 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 208 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 231 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 256 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 283 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 312 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 343 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 376 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 411 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyevent.sip"
#include <qkeyevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 450 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyevent.sip"
#include <qkeyevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 491 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyevent.sip"
#include <qkeyevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmouseevent.sip"
#include <qmouseevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousehandler.sip"
#include <qmousehandler.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousehandler.sip"
#include <qmousehandler.h>
#line 536 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_Qt3DInput[] = {
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', 'A', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'o', 'r', ':', ':', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'c', 't', 'i', 'o', 'n', 'I', 'n', 'p', 'u', 't', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', 'I', 'n', 'p', 'u', 't', '*', '>', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', '*', '>', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', ':', ':', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'W', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', ':', ':', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'c', 't', 'i', 'o', 'n', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', ':', ':', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'W', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', ':', ':', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'x', 'i', 's', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'A', 'x', 'i', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'A', 'x', 'e', 's', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'c', 't', 'i', 'o', 'n', '*', '>', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'n', 'a', 'l', 'o', 'g', 'A', 'x', 'i', 's', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', 'A', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'B', 'u', 't', 't', 'o', 'n', 'A', 'x', 'i', 's', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', '*', '>', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'I', 'n', 'p', 'u', 't', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'I', 'n', 'p', 'u', 't', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'L', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'U', 'p', 'd', 'a', 't', 'e', 'A', 'x', 'e', 's', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 's', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'c', 't', 'i', 'o', 'n', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'I', 'n', 'p', 'u', 't', 'A', 's', 'p', 'e', 'c', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'I', 'n', 'p', 'u', 't', 'C', 'h', 'o', 'r', 'd', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'W', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'A', 'x', 'e', 's', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', 0,
    'b', 'u', 't', 't', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'a', 'd', 'Z', 'o', 'n', 'e', 'R', 'a', 'd', 'i', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'K', 'e', 'y', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'M', 'o', 'u', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'v', 'e', 'n', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'S', 'i', 'g', 'n', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'D', 'e', 'a', 'd', 'Z', 'o', 'n', 'e', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 'D', 'o', 'w', 'n', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', ':', ':', 'Q', 'A', 'x', 'i', 's', 0,
    'b', 'u', 't', 't', 'o', 'n', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'S', 'm', 'o', 'o', 't', 'h', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'C', 'o', 'n', 't', 'r', 'o', 'l', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', 0,
    'a', 's', 't', 'e', 'r', 'i', 's', 'k', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', '1', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', '2', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', '3', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', '4', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'i', 's', 'S', 'm', 'o', 'o', 't', 'h', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'v', 'e', 'l', 'o', 'c', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 'U', 'p', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'K', 'e', 'y', 'p', 'a', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'a', 'd', 'd', 'A', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    'a', 'x', 'i', 's', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'a', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', 'I', 'd', 's', 0,
    'b', 'a', 'c', 'k', 't', 'a', 'b', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'b', 'u', 't', 't', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'b', 'u', 't', 't', 'o', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'a', 'd', 'Z', 'o', 'n', 'e', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'C', 'o', 'd', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 0,
    's', 'e', 't', 'E', 'v', 'e', 'n', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'S', 'h', 'i', 'f', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'M', 'o', 'u', 's', 'e', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '0', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '1', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '2', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '3', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '4', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '5', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '6', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '7', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '8', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'i', 'g', 'i', 't', '9', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'd', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'e', 's', 'c', 'a', 'p', 'e', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'h', 'a', 'n', 'g', 'u', 'p', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'r', 'e', 't', 'u', 'r', 'n', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 0,
    's', 'm', 'o', 'o', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'M', 'e', 't', 'a', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'M', 'i', 'd', 'd', 'l', 'e', 'B', 'u', 't', 't', 'o', 'n', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'x', 'i', 's', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'n', 't', 'e', 'r', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'p', 'r', 'e', 's', 's', 'A', 'n', 'd', 'H', 'o', 'l', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'r', 'i', 'g', 'h', 't', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    's', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'p', 'a', 'c', 'e', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'l', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'R', 'i', 'g', 'h', 't', 'B', 'u', 't', 't', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 0,
    'a', 'd', 'd', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 0,
    'a', 'x', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'x', 'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'c', 'k', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'b', 'u', 't', 't', 'o', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'b', 'u', 't', 't', 'o', 'n', 'N', 'a', 'm', 'e', 's', 0,
    'c', 'a', 'l', 'l', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'o', 'w', 'n', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'v', 'e', 'n', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'f', 'l', 'i', 'p', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'l', 'e', 'f', 't', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'm', 'e', 'n', 'u', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'h', 'o', 'r', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 'n', 'p', 'u', 't', 0,
    's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'B', 'a', 'c', 'k', 'B', 'u', 't', 't', 'o', 'n', 0,
    'L', 'e', 'f', 't', 'B', 'u', 't', 't', 'o', 'n', 0,
    'N', 'o', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'a', 'n', 'g', 'l', 'e', 'D', 'e', 'l', 't', 'a', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'x', 'i', 's', 0,
    's', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'x', 'i', 's', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'y', 'e', 's', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'a', 'd', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'x', 'i', 's', 'C', 'o', 'u', 'n', 't', 0,
    'a', 'x', 'i', 's', 'N', 'a', 'm', 'e', 's', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'n', 'o', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 's', 0,
    'N', 'o', 'B', 'u', 't', 't', 'o', 'n', 0,
    'V', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    'a', 'd', 'd', 'C', 'h', 'o', 'r', 'd', 0,
    'a', 'd', 'd', 'I', 'n', 'p', 'u', 't', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'd', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 0,
    'v', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    'a', 'c', 't', 'i', 'o', 'n', 's', 0,
    'a', 'd', 'd', 'A', 'x', 'i', 's', 0,
    'a', 'u', 't', 'o', 'r', 'e', 'p', 0,
    'b', 'u', 't', 't', 'o', 'n', 's', 0,
    'c', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'e', 'n', 't', 'e', 'r', 'e', 'd', 0,
    'm', 'a', 't', 'c', 'h', 'e', 's', 0,
    'p', 'r', 'e', 's', 's', 'e', 'd', 0,
    's', 'e', 't', 'A', 'x', 'e', 's', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 0,
    'w', 'a', 's', 'H', 'e', 'l', 'd', 0,
    'W', 'h', 'e', 'e', 'l', 'X', 0,
    'W', 'h', 'e', 'e', 'l', 'Y', 0,
    'b', 'u', 't', 't', 'o', 'n', 0,
    'c', 'h', 'o', 'r', 'd', 's', 0,
    'e', 'x', 'i', 't', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 's', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 0,
    's', 'c', 'a', 'l', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'w', 'h', 'e', 'e', 'l', 0,
    'a', 'x', 'e', 's', 0,
    'a', 'x', 'i', 's', 0,
    't', 'e', 'x', 't', 0,
    't', 'y', 'p', 'e', 0,
    'k', 'e', 'y', 0,
    'x', 0,
};

int sipVH_Qt3DInput_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QStringList sipVH_Qt3DInput_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

int sipVH_Qt3DInput_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_Qt3DInput_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_Qt3DInput_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_Qt3DInput_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_Qt3DInput_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_Qt3DInput_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_Qt3DInput_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_Qt3DInput_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QSceneChangePtr& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QSceneChangePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_Qt3DInput_QAbstractPhysicalDevice(void **);}
static const sipTypeDef *sipSubClass_Qt3DInput_QAbstractPhysicalDevice(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 36 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
        static struct class_graph {
            const char *name;
            sipTypeDef **type;
            int yes, no;
        } graph[] = {
            {sipName_Qt3DInput__QAbstractActionInput, &sipType_Qt3DInput_QAbstractActionInput, 15, 1},
            {sipName_Qt3DInput__QAbstractAxisInput, &sipType_Qt3DInput_QAbstractAxisInput, 18, 2},
            {sipName_Qt3DInput__QAbstractPhysicalDevice, &sipType_Qt3DInput_QAbstractPhysicalDevice, 20, 3},
            {sipName_Qt3DInput__QAction, &sipType_Qt3DInput_QAction, -1, 4},
            {sipName_Qt3DInput__QAxis, &sipType_Qt3DInput_QAxis, -1, 5},
        #if QT3DINPUT_VERSION >= 0x050800
            {sipName_Qt3DInput__QAxisAccumulator, &sipType_Qt3DInput_QAxisAccumulator, -1, 6},
        #else
            {0, 0, -1, 6},
        #endif
            {sipName_Qt3DInput__QAxisSetting, &sipType_Qt3DInput_QAxisSetting, -1, 7},
            {sipName_Qt3DInput__QInputAspect, &sipType_Qt3DInput_QInputAspect, -1, 8},
            {sipName_Qt3DInput__QInputSettings, &sipType_Qt3DInput_QInputSettings, -1, 9},
            {sipName_Qt3DInput__QKeyEvent, &sipType_Qt3DInput_QKeyEvent, -1, 10},
            {sipName_Qt3DInput__QKeyboardHandler, &sipType_Qt3DInput_QKeyboardHandler, -1, 11},
            {sipName_Qt3DInput__QLogicalDevice, &sipType_Qt3DInput_QLogicalDevice, -1, 12},
            {sipName_Qt3DInput__QMouseEvent, &sipType_Qt3DInput_QMouseEvent, -1, 13},
            {sipName_Qt3DInput__QMouseHandler, &sipType_Qt3DInput_QMouseHandler, -1, 14},
            {sipName_Qt3DInput__QWheelEvent, &sipType_Qt3DInput_QWheelEvent, -1, -1},
            {sipName_Qt3DInput__QActionInput, &sipType_Qt3DInput_QActionInput, -1, 16},
            {sipName_Qt3DInput__QInputChord, &sipType_Qt3DInput_QInputChord, -1, 17},
            {sipName_Qt3DInput__QInputSequence, &sipType_Qt3DInput_QInputSequence, -1, -1},
            {sipName_Qt3DInput__QAnalogAxisInput, &sipType_Qt3DInput_QAnalogAxisInput, -1, 19},
            {sipName_Qt3DInput__QButtonAxisInput, &sipType_Qt3DInput_QButtonAxisInput, -1, -1},
            {sipName_Qt3DInput__QKeyboardDevice, &sipType_Qt3DInput_QKeyboardDevice, -1, 21},
            {sipName_Qt3DInput__QMouseDevice, &sipType_Qt3DInput_QMouseDevice, -1, -1},
        };
        
        int i = 0;
        
        sipType = NULL;
        
        do
        {
            struct class_graph *cg = &graph[i];
        
            if (cg->name != NULL && sipCpp->inherits(cg->name))
            {
                sipType = *cg->type;
                i = cg->yes;
            }
            else
                i = cg->no;
        }
        while (i >= 0);
#line 880 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QAxisAccumulator__SourceAxisType, SIP_NULLPTR, 0}, sipNameNr_SourceAxisType, 12, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QMouseDevice__Axis, SIP_NULLPTR, 0}, sipNameNr_Axis, 24, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QMouseEvent__Buttons, SIP_NULLPTR, 0}, sipNameNr_Buttons, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QMouseEvent__Modifiers, SIP_NULLPTR, 0}, sipNameNr_Modifiers, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QWheelEvent__Buttons, SIP_NULLPTR, 0}, sipNameNr_Buttons, 31, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DInput__QWheelEvent__Modifiers, SIP_NULLPTR, 0}, sipNameNr_Modifiers, 31, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_Qt3DInput[] = {
    &sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAbstractActionInput.mtd_base,
    &sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAbstractAxisInput.mtd_base,
    &sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAction.mtd_base,
    &sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAxis.mtd_base,
    &sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAxisSetting.mtd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAbstractActionInput.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAbstractAxisInput.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAbstractPhysicalDevice.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAction.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QActionInput.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAnalogAxisInput.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAxis.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAxisAccumulator.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QAxisSetting.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QButtonAxisInput.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QInputAspect.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QInputChord.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QInputSequence.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QInputSettings.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QKeyEvent.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QKeyboardDevice.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QKeyboardHandler.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QLogicalDevice.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QMouseDevice.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QMouseEvent.ctd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QMouseHandler.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QPhysicalDeviceCreatedChangeBase.ctd_base,
    &sipTypeDef_Qt3DInput_Qt3DInput_QWheelEvent.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_Qt3DInput_QtCore[] = {
    {"QChildEvent"},
    {"QEvent"},
    {"QEvent::Type"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVector<int>"},
    {"Qt::KeyboardModifiers"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DInput_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_Qt3DInput_QtGui[] = {
    {"QKeyEvent"},
    {"QKeySequence::StandardKey"},
    {"QMouseEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DCore. */
sipImportedTypeDef sipImportedTypes_Qt3DInput_Qt3DCore[] = {
    {"QSharedPointer<Qt3DCore::QSceneChange>"},
    {"QVector<Qt3DCore::QNodeId>"},
    {"Qt3DCore::QAbstractAspect"},
    {"Qt3DCore::QComponent"},
    {"Qt3DCore::QNode"},
    {"Qt3DCore::QNodeCreatedChangeBase"},
    {"Qt3DCore::QSceneChange"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_Qt3DInput_QtCore, sipImportedVirtErrorHandlers_Qt3DInput_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_Qt3DInput_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DCore", sipImportedTypes_Qt3DInput_Qt3DCore, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_Qt3DInput_QAbstractPhysicalDevice, {4, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_Qt3DInput = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_Qt3DInput,
    0,
    sipStrings_Qt3DInput,
    importsTable,
    SIP_NULLPTR,
    34,
    sipExportedTypes_Qt3DInput,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_Qt3DInput;

sip_qt_metaobject_func sip_Qt3DInput_qt_metaobject;
sip_qt_metacall_func sip_Qt3DInput_qt_metacall;
sip_qt_metacast_func sip_Qt3DInput_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_Qt3DInput()
#else
PyMODINIT_FUNC PyInit_Qt3DInput()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.Qt3DInput",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_Qt3DInput = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_Qt3DInput == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_Qt3DInput, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_Qt3DInput_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_Qt3DInput_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_Qt3DInput_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_Qt3DInput_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_Qt3DInput, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
